#!/bin/sh
#
# build_localized_adobe_reader_debian_package.sh
#
# Build a debian package for a localized Adobe Reader
#
if test $# -lt 3 
then 
  echo "Use three parameters."
  echo "  locale      - e.g. deu for german"
  echo "  version     - e.g. 7.0"
  echo "  subversion  - e.g. 9-1.i386"
  exit 1 
fi

# Three parmameters
# VER=7.0; SUB_VERSION=0-1.i386; LOCAL=deu
LOCAL=$1
VER=$2
SUB_VERSION=$3
ACRO_VERSION=${LOCAL}-${VER}.${SUB_VERSION} 
LIBDIR=/usr/lib
LDAP=$LIBDIR/libldap.so.2
LBER=$LIBDIR/liblber.so.2

cleanup () {
	# cleanup
	rm -rf usr
	rm -rf AdobeReader
	rm -rf AdobeReader_${ACRO_VERSION} 
}

# In case of Ctrl-C
canceled() {
    sync
    echo =================
    echo Program canceled.
    cleanup;
    exit 1
}

trap "canceled;" 2 15



if test -e $LDAP
then
	echo LDAP filecheck OK ...
else
	echo Please install ldap2 first.
	echo "   apt-get install libldap2"
	exit 1
fi


if test -e AdobeReader_${ACRO_VERSION}.tar.gz
then 
	echo Adobe filecheck OK ...
	cleanup;
else
	echo Wrong params for Adobe file.
	echo File AdobeReader_${ACRO_VERSION}.tar.gz does not exist.
	echo The following files might be correct.
	echo ;
	ls Adobe*.tar.gz
	echo ;
	exit 1
fi


tar zxvf AdobeReader_${ACRO_VERSION}.tar.gz
fakeroot mkdir -p usr/bin usr/local/Adobe/Acrobat${VER}
fakeroot tar -C usr/local/Adobe/Acrobat${VER} \
   -xvf AdobeReader/COMMON.TAR
fakeroot tar -C usr/local/Adobe/Acrobat${VER} \
   -xvf AdobeReader/ILINXR.TAR
fakeroot ln -s \
   /usr/local/Adobe/Acrobat7.0/bin/acroread usr/bin/acroread
fakeroot ln -s $LDAP \
   usr/local/Adobe/Acrobat7.0/Reader/intellinux/lib/libldap.so.2
fakeroot ln -s $LBER \
   usr/local/Adobe/Acrobat7.0/Reader/intellinux/lib/liblber.so.2
fakeroot tar zcvf AdobeReader_${ACRO_VERSION}.tgz ./usr
fakeroot alien AdobeReader_${ACRO_VERSION}.tgz

cleanup;

